Rename getLocationIndicatorActive/setLocationIndicatorActive

This commit renames
getLocationIndicatorActive/setLocationIndicatorActive
No functional changes.

Tested: built bmcweb successfully and Validator passes

Signed-off-by: George Liu <liuxiwei@inspur.com>
Change-Id: I0c5d538c1dd9f0d8dd1e6ae4d8ba4f606b804373
Signed-off-by: Lakshmi Yadlapati <lakshmiy@us.ibm.com>
diff --git a/redfish-core/lib/led.hpp b/redfish-core/lib/led.hpp
index ff77ddc..b5d12fb 100644
--- a/redfish-core/lib/led.hpp
+++ b/redfish-core/lib/led.hpp
@@ -156,13 +156,13 @@
 }
 
 /**
  * @brief Retrieves identify led group properties over dbus
  *
  * @param[in] asyncResp     Shared pointer for generating response message.
  *
  * @return None.
  */
-inline void getLocationIndicatorActive(
+inline void getSystemLocationIndicatorActive(
     const std::shared_ptr<bmcweb::AsyncResp>& asyncResp)
 {
     BMCWEB_LOG_DEBUG("Get LocationIndicatorActive");
@@ -214,14 +214,14 @@
 }
 
 /**
  * @brief Sets identify led group properties
  *
  * @param[in] asyncResp     Shared pointer for generating response message.
  * @param[in] ledState  LED state passed from request
  *
  * @return None.
  */
-inline void setLocationIndicatorActive(
+inline void setSystemLocationIndicatorActive(
     const std::shared_ptr<bmcweb::AsyncResp>& asyncResp, const bool ledState)
 {
     BMCWEB_LOG_DEBUG("Set LocationIndicatorActive");
@@ -156,13 +156,13 @@
 
 /**
- * @brief Retrieves identify led group properties over dbus
+ * @brief Retrieves identify system led group properties over dbus
  *
  * @param[in] asyncResp     Shared pointer for generating response message.
@@ -214,14 +214,14 @@
 
 /**
- * @brief Sets identify led group properties
+ * @brief Sets identify system led group properties
  *
  * @param[in] asyncResp     Shared pointer for generating response message.